==> haskell-vault-0.3.0.6-9-i686.pkg.tar.xz: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vault
version: 0.3.0.6
id: vault-0.3.0.6-E6e1xEGSbzvJDLaCWzJ9Cl
key: vault-0.3.0.6-E6e1xEGSbzvJDLaCWzJ9Cl
license: BSD3
copyright: (c) Heinrich Apfelmus 2011-2013
maintainer: Heinrich Apfelmus <apfelmus at quantentunnel de>
homepage: https://github.com/HeinrichApfelmus/vault
synopsis: a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.
    .
    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.
    .
    Also provided is a /locker/ type, representing a store for a single element.
category: Data
author: Heinrich Apfelmus, Elliott Hird
exposed: True
exposed-modules:
    Data.Vault.Lazy Data.Vault.Strict Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Unique.Really
abi: 1364bdb91971f731ca1ae0b40da0b178
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/vault-0.3.0.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/vault-0.3.0.6
data-dir: /usr/share/i386-linux-ghc-8.0.1/vault-0.3.0.6
hs-libraries: HSvault-0.3.0.6-E6e1xEGSbzvJDLaCWzJ9Cl
depends:
    base-4.9.0.0 containers-0.5.7.1
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
haddock-interfaces: /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html: /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vault-0.3.0.7-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vault
version: 0.3.0.7
id: vault-0.3.0.7-7ljhTnQetmMK9FZWfMdQzN
key: vault-0.3.0.7-7ljhTnQetmMK9FZWfMdQzN
license: BSD3
copyright: (c) Heinrich Apfelmus 2011-2013
maintainer: Heinrich Apfelmus <apfelmus at quantentunnel de>
homepage: https://github.com/HeinrichApfelmus/vault
synopsis: a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.
    .
    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.
    .
    Also provided is a /locker/ type, representing a store for a single element.
category: Data
author: Heinrich Apfelmus, Elliott Hird
exposed: True
exposed-modules:
    Data.Vault.Lazy Data.Vault.Strict Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Unique.Really
abi: 1baa596c1cffe1580f9c146431775e45
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/vault-0.3.0.7
library-dirs: /usr/lib/ghc-8.0.1/site-local/vault-0.3.0.7
data-dir: /usr/share/i386-linux-ghc-8.0.1/vault-0.3.0.7
hs-libraries: HSvault-0.3.0.7-7ljhTnQetmMK9FZWfMdQzN
depends:
    base-4.9.0.0 containers-0.5.7.1
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
haddock-interfaces: /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html: /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
